import React,{useState,useEffect} from 'react';
import ReactDOM from 'react-dom';
import {scaleLinear, extent,axisLeft,scaleOrdinal} from 'd3';

import {useData} from './useData';
import {Marks} from './Marks';
import { Dropdown } from './Dropdown'
import { ColorLegend } from './ColorLegend'


const width = window.innerWidth;
const height = window.innerHeight;
const margin = { top: 20,right: 300,bottom: 20,left: 20 }
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;



let options = [
   {value:'petal_width',lable: 'Petal Width'},
   {value:'sepal_length',lable: 'Sepal Length'},
   {value:'sepal_width',lable: 'Sepal Width'},
   {value:'species',lable: 'Species'},
   {value:'petal_length',lable:'Petal Length'}
]

const App = () => {  
  
  const data = useData();
  const iniXAttr = 'petal_length';
	const [XAttr , setXAttr] = useState(iniXAttr);

	const xValue = d => d[XAttr];
	const yValue = d => d.sepal_width;
	const colorValue = d => d.species;
	console.log(XAttr);

 	if(!data)
    return <div>Loading...</div>
  console.log(data[0]);
  
  const xScale = scaleLinear()
  							.domain(extent(data,xValue))
  							.range([0,innerWidth])
  const yScale = scaleLinear()
  							.domain(extent(data,yValue))
  							.range([0,innerHeight])
  
  const colorScale = scaleOrdinal()
  									.domain(data.map(colorValue))
      							.range(['#E6842A', '#137B80', '#8E6C8A']);

  
    
  return (
    <>
  <Dropdown options = {options} selValue = {XAttr} onSelValChange = {setXAttr}/>
      
    <svg className="marks" width={width} height={height}>
       <g transform={`translate(${innerWidth + 100},50)`}> 
     <ColorLegend colorScale={colorScale}/>
      </g>
       <g transform={`translate(${margin.left},${margin.top})`}>
     	<Marks 
        data={data} 
        xScale={xScale} 
        xValue={xValue} 
        
        yScale={yScale} 
        yValue={yValue}
        
        colorScale={colorScale}
        colorValue={colorValue}
        />        
      </g>
    
    </svg>
      </>
      )
};

ReactDOM.render(<App />, document.getElementById('root'));
